@@ -33,7 +33,6 @@
 #'
 #' @slot .heap  \code{C++} object representing a heap
 #' @slot .key.class  the class of the keys
-#' @slot .value.class  the class of the values
 #'
 setClass("binomial_heap", contains = "heap")
 
@@ -47,47 +46,20 @@ setClass("binomial_heap", contains = "heap")
 #'  i.e. a tree-like data structure satisfying the \emph{min-heap} property.
 #'
 #' @param key.class  the primitive class type of the keys
-#' @param value.class  the primitive class type of the values
 #'
 #' @return returns a new \code{binomial_heap} object
 #'
 binomial_heap <- function(
-  key.class = c("character", "numeric", "integer"),
-  value.class = c("character", "numeric", "integer"))
+  key.class = c("character", "numeric", "integer"))
 {
   key.class   <- match.arg(key.class)
-  value.class <- match.arg(value.class)
-
-  if (key.class == "character")
-  {
-    if (value.class == "character")
-      heap <- methods::new(binomial_heap_ss)
-    else if (value.class == "integer")
-      heap <- methods::new(binomial_heap_si)
-    else
-      heap <- methods::new(binomial_heap_sd)
-  }
-  else if (key.class == "numeric")
-  {
-    if (value.class == "character")
-      heap <- methods::new(binomial_heap_ds)
-    else if (value.class == "integer")
-      heap <- methods::new(binomial_heap_di)
-    else
-      heap <- methods::new(binomial_heap_dd)
-  }
-  else
-  {
-    if (value.class == "character")
-      heap <- methods::new(binomial_heap_is)
-    else if (value.class == "integer")
-      heap <- methods::new(binomial_heap_ii)
-    else
-      heap <- methods::new(binomial_heap_id)
-  }
+  heap <- switch(key.class,
+                 "character" = methods::new(binomial_heap_s),
+                 "numeric"   = methods::new(binomial_heap_d),
+                 "integer"   = methods::new(binomial_heap_i),
+                 stop("Error defining key class"))
 
   methods::new("binomial_heap",
                .key.class = key.class,
-               .value.class = value.class,
                .heap = heap)
 }
