@@ -31,17 +31,12 @@
 #'
 #' @slot .map  \code{C++} object representing a mapping
 #' @slot .key.class  the class of the keys
-#' @slot .value.class  the class of the values
 #'
 setClass(
   "map",
   contains = "VIRTUAL",
-  slots = list(.map = "ANY",
-               .key.class = "character",
-               .value.class = "character"),
-  prototype = prototype(.map = NULL,
-                        .key.class = NA_character_,
-                        .value.class = NA_character_)
+  slots = list(.map = "ANY", .key.class = "character"),
+  prototype = prototype(.map = NULL, .key.class = NA_character_)
 )
 
 
@@ -60,14 +55,14 @@ setClass(
   clazz <- class(object)[1]
   pf <- ifelse(clazz == "bimap", " <--> ", " -> ")
   cat(paste0("An object of class ", clazz, "<",
-             object@.key.class, ",", object@.value.class,
+             object@.key.class, ",T",
              ">\n\n"))
   li <- head(object)
   for (l in names(li))
   {
     e <- li[[l]]
     if (is.null(e)) e <- "NULL"
-    cat(paste0(l, pf, paste(e, collapse = ", "), "\n"))
+    cat(paste0(l, pf, class(e), "\n"))
   }
   if (is.null(li))
     cat(paste0("NULL", pf, "NULL", "\n"))
